@@ -1,19 +1,20 @@
-
 """
 SunPy
 =====
+
 An open-source Python library for Solar Physics data analysis.
+
 Web Links
 ---------
-Homepage: http://sunpy.org
-Documentation: http://docs.sunpy.org/en/stable/
+Homepage: https://sunpy.org
+Documentation: https://docs.sunpy.org/en/stable/
 """
 # Enforce Python version check during package import.
 # This is the same check as the one at the top of setup.py
 import os
 import sys
 
-__minimum_python_version__ = "2.7"
+__minimum_python_version__ = "3.6"
 
 
 class UnsupportedPythonError(Exception):
@@ -27,20 +28,13 @@ if sys.version_info < tuple((int(val) for val in __minimum_python_version__.spli
 try:
     _SUNPY_SETUP_
 except NameError:
-    try:
-        import builtins
-    except ImportError:
-        import __builtin__ as builtins
+    import builtins
     builtins._SUNPY_SETUP_ = False
 
 try:
     from .version import version as __version__
 except ImportError:
     __version__ = ''
-try:
-    from .version import githash as __githash__
-except ImportError:
-    __githash__ = ''
 
 if not _SUNPY_SETUP_:
     from sunpy.util.config import load_config, print_config
@@ -52,4 +46,12 @@ if not _SUNPY_SETUP_:
     # Load user configuration
     config = load_config()
 
+    import logging
+
+    # Use the root logger as a dummy log before initializing Astropy's logger
+    log = logging.getLogger()
+
+    from sunpy.util.logger import _init_log
+    log = _init_log(config=config)
+
     __all__ = ['config', 'self_test', 'system_info']
