@@ -6,7 +6,7 @@
 from datetime import datetime
 
 import pytest
-from astropy import units as u
+import astropy.units as u
 
 from sunpy.database.database import Database
 from sunpy.database import tables
@@ -14,7 +14,6 @@ from sunpy.database.attrs import walker, Starred, Tag, Path, DownloadTime,\
     FitsHeaderEntry
 from sunpy.net.attr import DummyAttr, AttrAnd, AttrOr
 from sunpy.net import vso
-from sunpy.extern.six.moves import range
 
 
 @pytest.fixture
@@ -406,24 +405,39 @@ def test_walker_create_fitsheader_inverted(session):
 @pytest.mark.remote_data
 def test_walker_create_vso_instrument(vso_session):
     entries = walker.create(vso.attrs.Instrument('RHESSI'), vso_session)
+    # TODO: Flaky
     expected = [
         tables.DatabaseEntry(id=1, source=u'RHESSI', provider=u'LSSP',
                              physobs=u'intensity',
-                             fileid=u'/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
-                             observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
-                             observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
-                             instrument='RHESSI', wavemin=0.4132806579880238,
+                             fileid=u'/hessidata/2011/09/20/hsi_20110920_010920',
+                             observation_time_start=datetime(2011, 9, 20, 1, 9, 20),
+                             observation_time_end=datetime(2011, 9, 20, 2, 27, 40),
+                             instrument=u'RHESSI', wavemin=0.4132806579880238,
                              wavemax=7.293188082141598e-05),
         tables.DatabaseEntry(id=2, source=u'RHESSI', provider=u'LSSP',
                              physobs=u'intensity',
-                             fileid=u'/hessidata/2011/09/20/hsi_20110920_010920_001.fits',
+                             fileid=u'/hessidata/2011/09/19/hsi_20110919_233340',
+                             observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
+                             observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
+                             instrument=u'RHESSI', wavemin=0.4132806579880238,
+                             wavemax=7.293188082141598e-05)]
+    expected_2 = [
+        tables.DatabaseEntry(id=1, source=u'RHESSI', provider=u'LSSP',
+                             physobs=u'intensity',
+                             fileid=u'/hessidata/2011/09/19/hsi_20110919_233340',
+                             observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
+                             observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
+                             instrument=u'RHESSI', wavemin=0.4132806579880238,
+                             wavemax=7.293188082141598e-05),
+        tables.DatabaseEntry(id=2, source=u'RHESSI', provider=u'LSSP',
+                             physobs=u'intensity',
+                             fileid=u'/hessidata/2011/09/20/hsi_20110920_010920',
                              observation_time_start=datetime(2011, 9, 20, 1, 9, 20),
                              observation_time_end=datetime(2011, 9, 20, 2, 27, 40),
-                             instrument='RHESSI', wavemin=0.4132806579880238,
+                             instrument=u'RHESSI', wavemin=0.4132806579880238,
                              wavemax=7.293188082141598e-05)]
     assert len(entries) == len(expected)
-    for e in entries:
-        assert e in entries
+    assert entries in [expected, expected_2]
 
 
 @pytest.mark.remote_data
@@ -440,13 +454,19 @@ def test_walker_create_time(vso_session):
         datetime(2011, 9, 17, 0, 0, 0), datetime(2011, 9, 20, 0, 0, 0))
     entries = walker.create(time, vso_session)
     assert len(entries) == 1
-    expected = tables.DatabaseEntry(id=1, source=u'RHESSI', provider=u'LSSP',
-                                    physobs=u'intensity',
-                                    fileid=u'/hessidata/2011/09/19/hsi_20110919_233340_002.fits',
-                                    observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
-                                    observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
-                                    instrument=u'RHESSI',
-                                    size=-1.0,
-                                    wavemin=0.4132806579880238,
-                                    wavemax=7.293188082141598e-05)
-    assert expected in entries
+    # TODO: Flaky and the only change the id number.
+    assert entries in [
+        [tables.DatabaseEntry(id=1, source=u'RHESSI', provider=u'LSSP',
+                              physobs=u'intensity',
+                              fileid=u'/hessidata/2011/09/19/hsi_20110919_233340',
+                              observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
+                              observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
+                              instrument=u'RHESSI', wavemin=0.4132806579880238,
+                              wavemax=7.293188082141598e-05)],
+        [tables.DatabaseEntry(id=2, source=u'RHESSI', provider=u'LSSP',
+                              physobs=u'intensity',
+                              fileid=u'/hessidata/2011/09/19/hsi_20110919_233340',
+                              observation_time_start=datetime(2011, 9, 19, 23, 33, 40),
+                              observation_time_end=datetime(2011, 9, 20, 1, 9, 20),
+                              instrument=u'RHESSI', wavemin=0.4132806579880238,
+                              wavemax=7.293188082141598e-05)]]
