@@ -3,35 +3,30 @@
 # This module was developed with funding provided by
 # the Google Summer of Code (2013).
 
-from __future__ import absolute_import
-
-import glob
 import os
-import os.path
+import glob
 import shutil
+import os.path
+import configparser
 
 import pytest
 import sqlalchemy
 
 from astropy import units
+from astropy.utils.exceptions import AstropyUserWarning
 
 import sunpy
-from sunpy.database import Database, EntryAlreadyAddedError,\
-    EntryAlreadyStarredError, EntryAlreadyUnstarredError, NoSuchTagError,\
-    EntryNotFoundError, TagAlreadyAssignedError, disable_undo, split_database
-from sunpy.database.tables import DatabaseEntry, Tag, FitsHeaderEntry,\
-    FitsKeyComment, JSONDump
-from sunpy.database.commands import EmptyCommandStackError, NoSuchEntryError
-from sunpy.database.caching import LRUCache, LFUCache
-from sunpy.database import attrs
-from sunpy.net import vso, hek
-from sunpy.data.test.waveunit import waveunitdir
-from sunpy.io import fits
-from sunpy.extern.six.moves import range
-from sunpy.extern.six.moves import configparser
-from sunpy.net import Fido, attrs as net_attrs
-
 import sunpy.data.test
+from sunpy.io import fits
+from sunpy.net import Fido, hek, vso
+from sunpy.net import attrs as net_attrs
+from sunpy.database import (Database, NoSuchTagError, EntryNotFoundError, EntryAlreadyAddedError,
+                            TagAlreadyAssignedError, EntryAlreadyStarredError,
+                            EntryAlreadyUnstarredError, attrs, disable_undo, split_database)
+from sunpy.database.tables import Tag, JSONDump, DatabaseEntry, FitsKeyComment, FitsHeaderEntry
+from sunpy.database.caching import LFUCache, LRUCache
+from sunpy.database.commands import NoSuchEntryError, EmptyCommandStackError
+from sunpy.data.test.waveunit import waveunitdir
 
 testpath = sunpy.data.test.rootdir
 RHESSI_IMAGE = os.path.join(testpath, 'hsi_image_20101016_191218.fits')
@@ -120,7 +115,7 @@ def filled_database():
 
 
 def test_config_url(monkeypatch):
-    monkeypatch.setattr("sunpy.config", configparser.SafeConfigParser())
+    monkeypatch.setattr("sunpy.config", configparser.ConfigParser())
     url = 'sqlite:///'
     sunpy.config.add_section('database')
     sunpy.config.set('database', 'url', url)
@@ -129,7 +124,7 @@ def test_config_url(monkeypatch):
 
 
 def test_config_url_none(monkeypatch):
-    monkeypatch.setattr("sunpy.config", configparser.SafeConfigParser())
+    monkeypatch.setattr("sunpy.config", configparser.ConfigParser())
     with pytest.raises(configparser.NoSectionError):
         Database()
 
@@ -575,18 +570,18 @@ def test_add_entries_from_qr_ignore_duplicates(database, query_result):
 def test_add_entry_fido_search_result(database, fido_search_result):
     assert len(database) == 0
     database.add_from_fido_search_result(fido_search_result)
-    assert len(database) == 65
+    assert len(database) == 66
     database.undo()
     assert len(database) == 0
     database.redo()
-    assert len(database) == 65
+    assert len(database) == 66
 
 
 @pytest.mark.remote_data
 def test_add_entries_from_fido_search_result_JSOC_client(database):
     assert len(database) == 0
     search_result = Fido.search(
-        net_attrs.jsoc.Time('2014-01-01T00:00:00', '2014-01-01T01:00:00'),
+        net_attrs.Time('2014-01-01T00:00:00', '2014-01-01T01:00:00'),
         net_attrs.jsoc.Series('hmi.m_45s'),
         net_attrs.jsoc.Notify("sunpy@sunpy.org")
         )
@@ -598,7 +593,7 @@ def test_add_entries_from_fido_search_result_JSOC_client(database):
 def test_add_entries_from_fido_search_result_duplicates(database, fido_search_result):
     assert len(database) == 0
     database.add_from_fido_search_result(fido_search_result)
-    assert len(database) == 65
+    assert len(database) == 66
     with pytest.raises(EntryAlreadyAddedError):
         database.add_from_fido_search_result(fido_search_result)
 
@@ -607,14 +602,15 @@ def test_add_entries_from_fido_search_result_duplicates(database, fido_search_re
 def test_add_entries_from_fido_search_result_ignore_duplicates(database, fido_search_result):
     assert len(database) == 0
     database.add_from_fido_search_result(fido_search_result)
-    assert len(database) == 65
+    assert len(database) == 66
     database.add_from_fido_search_result(fido_search_result, True)
-    assert len(database) == 2*65
+    assert len(database) == 2*66
 
 
 def test_add_fom_path(database):
     assert len(database) == 0
-    database.add_from_dir(waveunitdir)
+    with pytest.warns(AstropyUserWarning, match='File may have been truncated'):
+        database.add_from_dir(waveunitdir)
     assert len(database) == 4
     database.undo()
     assert len(database) == 0
@@ -623,16 +619,19 @@ def test_add_fom_path(database):
 
 
 def test_add_fom_path_duplicates(database):
-    database.add_from_dir(waveunitdir)
+    with pytest.warns(AstropyUserWarning, match='File may have been truncated'):
+        database.add_from_dir(waveunitdir)
     assert len(database) == 4
-    with pytest.raises(EntryAlreadyAddedError):
+    with pytest.raises(EntryAlreadyAddedError), pytest.warns(AstropyUserWarning, match='File may have been truncated'):
         database.add_from_dir(waveunitdir)
 
 
 def test_add_fom_path_ignore_duplicates(database):
-    database.add_from_dir(waveunitdir)
+    with pytest.warns(AstropyUserWarning, match='File may have been truncated'):
+        database.add_from_dir(waveunitdir)
     assert len(database) == 4
-    database.add_from_dir(waveunitdir, ignore_already_added=True)
+    with pytest.warns(AstropyUserWarning, match='File may have been truncated'):
+        database.add_from_dir(waveunitdir, ignore_already_added=True)
     assert len(database) == 8
 
 
