@@ -9,7 +9,7 @@ the GOES/XRS instrument, see [Ref1]_.  GOES/XRS has become
 the "standard candle" for solar coronal observations due its longevity and
 consistency.  The GOES event list, based on GOES/XRS observations, has
 become the standard solar flare catalogue.
-See http://www.ngdc.noaa.gov/stp/solar/solarflares.html for information
+See https://www.ngdc.noaa.gov/stp/solar/solarflares.html for information
 on the GOES event list definitions and data.
 
 The functions in this module provide useful software to analyse GOES/XRS
@@ -41,33 +41,29 @@ References
 ----------
 
 .. [Ref1] Hanser, F.A., & Sellers, F.B. 1996, Proc. SPIE, 2812, 344
-.. [Ref2] Dere, K.P., et al. 2009 A&A, 498, 915 DOI: `10.1051/0004-6361/200911712 <https://dx.doi.org/10.1051/0004-6361/200911712>`__
+.. [Ref2] Dere, K.P., et al. 2009 A&A, 498, 915 DOI: `10.1051/0004-6361/200911712 <https://doi.org/10.1051/0004-6361/200911712>`__
 
 """
 
-from __future__ import absolute_import, division
-
-import os.path
-import datetime
 import csv
 import copy
 import socket
+import os.path
+import datetime
 from itertools import dropwhile
 
 import numpy as np
+import astropy.units as u
+from astropy.time import TimeDelta
 from scipy import interpolate
 from scipy.integrate import trapz, cumtrapz
-import astropy.units as u
-import pandas
 
-from sunpy.net import hek
+from sunpy.sun import constants
+from sunpy import timeseries
 from sunpy.time import parse_time
-from sunpy import config
-from sunpy import lightcurve
 from sunpy.util.net import check_download_file
+from sunpy.coordinates import sun
 from sunpy.util.config import get_and_create_download_dir
-from sunpy import sun
-from sunpy.coordinates import get_sunearth_distance
 
 GOES_CONVERSION_DICT = {'X': u.Quantity(1e-4, "W/m^2"),
                         'M': u.Quantity(1e-5, "W/m^2"),
@@ -104,11 +100,14 @@ def get_goes_event_list(timerange, goes_class_filter=None):
     timerange : `sunpy.time.TimeRange`
         The time range to download the event list for.
 
-    goes_class_filter: (optional) string
+    goes_class_filter: (optional) str
         A string specifying a minimum GOES class for inclusion in the list,
         e.g. 'M1', 'X2'.
 
     """
+    # Importing hek here to avoid calling code that relies on optional dependencies.
+    from sunpy.net import hek
+
     # use HEK module to search for GOES events
     client = hek.HEKClient()
     event_type = 'FL'
@@ -119,13 +118,13 @@ def get_goes_event_list(timerange, goes_class_filter=None):
     # between tstart and tend (using a GOES-class filter)
     if goes_class_filter:
         result = client.search(hek.attrs.Time(tstart, tend),
-                              hek.attrs.EventType(event_type),
-                              hek.attrs.FL.GOESCls > goes_class_filter,
-                              hek.attrs.OBS.Observatory == 'GOES')
+                               hek.attrs.EventType(event_type),
+                               hek.attrs.FL.GOESCls > goes_class_filter,
+                               hek.attrs.OBS.Observatory == 'GOES')
     else:
         result = client.search(hek.attrs.Time(tstart, tend),
-                              hek.attrs.EventType(event_type),
-                              hek.attrs.OBS.Observatory == 'GOES')
+                               hek.attrs.EventType(event_type),
+                               hek.attrs.OBS.Observatory == 'GOES')
 
     # want to condense the results of the query into a more manageable
     # dictionary
@@ -136,7 +135,7 @@ def get_goes_event_list(timerange, goes_class_filter=None):
 
     for r in result:
         goes_event = {
-            'event_date': parse_time(r['event_starttime']).date().strftime(
+            'event_date': parse_time(r['event_starttime']).strftime(
                 '%Y-%m-%d'),
             'start_time': parse_time(r['event_starttime']),
             'peak_time': parse_time(r['event_peaktime']),
@@ -150,10 +149,10 @@ def get_goes_event_list(timerange, goes_class_filter=None):
     return goes_event_list
 
 
-def calculate_temperature_em(goeslc, abundances="coronal",
+def calculate_temperature_em(goests, abundances="coronal",
                              download=False, download_dir=None):
     """
-    Calculates temperature and emission measure from a GOESLightCurve.
+    Calculates temperature and emission measure from a `~sunpy.timeseries.XRSTimeSeries`.
 
     This function calculates the isothermal temperature and
     corresponding volume emission measure of the solar soft X-ray
@@ -165,7 +164,7 @@ def calculate_temperature_em(goeslc, abundances="coronal",
 
     Parameters
     ----------
-    goeslc : `~sunpy.lightcurve.LightCurve`
+    goeslc : `~sunpy.timeseries.XRSTimeSeries`
         LightCurve object containing GOES flux data which MUST
         be in units of W/m^2.
 
@@ -188,12 +187,12 @@ def calculate_temperature_em(goeslc, abundances="coronal",
 
     Returns
     -------
-    lc_new : `~sunpy.lightcurve.LightCurve`
-        Contains same metadata and data as input GOESLightCurve with the
+    ts_new : `~sunpy.timeseries.XRSTimeSeries`
+        Contains same metadata and data as input timeseries with the
         following two additional data columns:
 
-        | lc_new.data.temperature - Array of temperatures [MK]
-        | lc_new.data.em - Array of volume emission measures [cm**-3]
+        | ts_new.data.temperature - Array of temperatures [MK]
+        | ts_new.data.em - Array of volume emission measures [cm**-3]
 
     Notes
     -----
@@ -227,55 +226,61 @@ def calculate_temperature_em(goeslc, abundances="coronal",
 
     Examples
     --------
+    >>> import sunpy.timeseries as ts
     >>> from sunpy.instr.goes import calculate_temperature_em
-    >>> import sunpy.lightcurve as lc
-    >>> time1 = "2014-01-01 00:00:00"
-    >>> time2 = "2014-01-01 00:00:08"
-    >>> goeslc = lc.GOESLightCurve.create(time1, time2)  # doctest: +REMOTE_DATA
-    >>> goeslc.data  # doctest: +REMOTE_DATA +FLOAT_CMP
-                                        xrsa      xrsb
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004
-
-    >>> goeslc_new = calculate_temperature_em(goeslc)  # doctest: +REMOTE_DATA
-    >>> goeslc_new.data  # doctest: +REMOTE_DATA +FLOAT_CMP
-                                        xrsa      xrsb  temperature            em
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004     6.270239  6.440648e+48
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004     6.270239  6.440648e+48
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004     6.273917  6.422208e+48
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004     6.304001  6.350370e+48
-
-
+    >>> from sunpy.data.sample import GOES_XRS_TIMESERIES  # doctest: +REMOTE_DATA
+    >>> goests = ts.TimeSeries(GOES_XRS_TIMESERIES)  # doctest: +REMOTE_DATA
+    >>> goests.data[0:10]  # doctest: +REMOTE_DATA
+                                           xrsa          xrsb
+    2011-06-06 23:59:59.961999893  1.000000e-09  1.887100e-07
+    2011-06-07 00:00:02.008999944  1.000000e-09  1.834600e-07
+    2011-06-07 00:00:04.058999896  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:06.104999900  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:08.151999950  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:10.201999903  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:12.248999953  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:14.298999906  1.000000e-09  1.834600e-07
+    2011-06-07 00:00:16.344999909  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:18.391999960  1.000000e-09  1.834600e-07
+    >>> goests_new = calculate_temperature_em(goests)  # doctest: +REMOTE_DATA
+    >>> goests_new.data[0:10]  # doctest: +REMOTE_DATA
+                                           xrsa          xrsb  temperature            em
+    2011-06-06 23:59:59.961999893  1.000000e-09  1.887100e-07     3.503510  2.190626e+48
+    2011-06-07 00:00:02.008999944  1.000000e-09  1.834600e-07     3.534262  2.055847e+48
+    2011-06-07 00:00:04.058999896  1.000000e-09  1.860900e-07     3.518700  2.122771e+48
+    2011-06-07 00:00:06.104999900  1.000000e-09  1.808400e-07     3.550100  1.990333e+48
+    2011-06-07 00:00:08.151999950  1.000000e-09  1.860900e-07     3.518700  2.122771e+48
+    2011-06-07 00:00:10.201999903  1.000000e-09  1.808400e-07     3.550100  1.990333e+48
+    2011-06-07 00:00:12.248999953  1.000000e-09  1.860900e-07     3.518700  2.122771e+48
+    2011-06-07 00:00:14.298999906  1.000000e-09  1.834600e-07     3.534262  2.055847e+48
+    2011-06-07 00:00:16.344999909  1.000000e-09  1.808400e-07     3.550100  1.990333e+48
+    2011-06-07 00:00:18.391999960  1.000000e-09  1.834600e-07     3.534262  2.055847e+48
     """
     # Check that input argument is of correct type
-    if not isinstance(goeslc, lightcurve.LightCurve):
-        raise TypeError("goeslc must be a LightCurve object.")
+    if not isinstance(goests, timeseries.XRSTimeSeries):
+        raise TypeError("goests must be a XRSTimeSeries object")
     if not download_dir:
         download_dir = get_and_create_download_dir()
 
     # Find temperature and emission measure with _goes_chianti_tem
     temp, em = _goes_chianti_tem(
-        u.Quantity(goeslc.data.xrsb, unit=u.W/(u.m)**2),
-        u.Quantity(goeslc.data.xrsa, unit=u.W/(u.m)**2),
-        satellite=goeslc.meta["TELESCOP"].split()[1],
-        date=goeslc.data.index[0],
+        goests.quantity("xrsb"),
+        goests.quantity("xrsa"),
+        satellite=goests.meta.metas[0]["TELESCOP"].split()[1],
+        date=goests.data.index[0],
         abundances=abundances, download=download, download_dir=download_dir)
 
-    # Enter results into new version of GOES LightCurve Object
-    # Use copy.deepcopy for replicating meta and data so that input
-    # lightcurve is not altered.
-    lc_new = lightcurve.LightCurve(meta=copy.deepcopy(goeslc.meta),
-                                   data=copy.deepcopy(goeslc.data))
-    lc_new.data["temperature"] = temp.value
-    lc_new.data["em"] = em.value
+    ts_new = timeseries.XRSTimeSeries(meta=copy.deepcopy(goests.meta),
+                                      data=copy.deepcopy(goests.data),
+                                      units=copy.deepcopy(goests.units))
+    ts_new = ts_new.add_column("temperature", temp)
+    ts_new = ts_new.add_column("em", em)
 
-    return lc_new
+    return ts_new
 
 
-@u.quantity_input(longflux=u.W/u.m/u.m, shortflux=u.W/u.m/u.m)
-def _goes_chianti_tem(longflux, shortflux, satellite=8,
+@u.quantity_input
+def _goes_chianti_tem(longflux: u.W/u.m/u.m, shortflux: u.W/u.m/u.m, satellite=8,
                       date=datetime.datetime.today(), abundances="coronal",
                       download=False, download_dir=None):
     """
@@ -297,7 +302,7 @@ def _goes_chianti_tem(longflux, shortflux, satellite=8,
         correct calibration of data.
         Default=8
 
-    date : `datetime.datetime` or `str`
+    date : `astropy.time.Time` or `str`
         Date when observations made.  Important for correctcalibration.
         Default=today
 
@@ -313,7 +318,7 @@ def _goes_chianti_tem(longflux, shortflux, satellite=8,
         launch of new GOES satellites since these files were last downloaded.
         Default=False
 
-    download_dir : (optional) string
+    download_dir : (optional) str
         The directory to download the GOES temperature and emission measure
         data files to.
         Default=SunPy default download directory
@@ -362,8 +367,8 @@ def _goes_chianti_tem(longflux, shortflux, satellite=8,
     --------
     >>> from sunpy.instr.goes import _goes_chianti_tem
     >>> from astropy.units import Quantity
-    >>> longflux = Quantity([7e-6, 7e-6], unit="W/m/m")
-    >>> shortflux = Quantity([7e-7, 7e-7], unit="W/m/m")
+    >>> longflux = Quantity([7e-6, 7e-6], unit="W/m**2")
+    >>> shortflux = Quantity([7e-7, 7e-7], unit="W/m**2")
     >>> temp, em = _goes_chianti_tem(longflux, shortflux, satellite=15,
     ...                              date='2014-04-16',
     ...                              abundances="coronal")  # doctest: +REMOTE_DATA
@@ -391,7 +396,7 @@ def _goes_chianti_tem(longflux, shortflux, satellite=8,
     # PREPARE DATA
     # GOES 6 long channel flux before 1983-Jun-28 must be corrected by a
     # factor of 4.43/5.32
-    if date < datetime.datetime(1983, 6, 28) and satellite == 6:
+    if date < parse_time((1983, 6, 28)) and satellite == 6:
         longflux_corrected = longflux*(4.43/5.32)
     else:
         longflux_corrected = longflux
@@ -421,8 +426,8 @@ def _goes_chianti_tem(longflux, shortflux, satellite=8,
     return temp, em
 
 
-@u.quantity_input(fluxratio=u.dimensionless_unscaled)
-def _goes_get_chianti_temp(fluxratio, satellite=8, abundances="coronal",
+@u.quantity_input
+def _goes_get_chianti_temp(fluxratio: u.one, satellite=8, abundances="coronal",
                            download=False, download_dir=None):
     """
     Calculates temperature from GOES flux ratio.
@@ -459,7 +464,7 @@ def _goes_get_chianti_temp(fluxratio, satellite=8, abundances="coronal",
         of new GOES satellites since these files were last downloaded.
         Default=False
 
-    download_dir : (optional) string
+    download_dir : (optional) str
         The directory to download the GOES temperature data file to.
         Default=SunPy default download directory
 
@@ -569,9 +574,10 @@ def _goes_get_chianti_temp(fluxratio, satellite=8, abundances="coronal",
     return temp
 
 
-@u.quantity_input(longflux=u.W/u.m/u.m, temp=u.MK)
-def _goes_get_chianti_em(longflux, temp, satellite=8, abundances="coronal",
-                         download=False, download_dir=None):
+@u.quantity_input
+def _goes_get_chianti_em(longflux: u.W/u.m/u.m, temp: u.MK, satellite=8,
+                         abundances="coronal", download=False,
+                         download_dir=None):
     """
     Calculates emission measure from GOES 1-8A flux and temperature.
 
@@ -732,7 +738,7 @@ def _goes_get_chianti_em(longflux, temp, satellite=8, abundances="coronal",
     return em
 
 
-def calculate_radiative_loss_rate(goeslc, force_download=False,
+def calculate_radiative_loss_rate(goests, force_download=False,
                                   download_dir=None):
     """
     Calculates radiative loss rate from GOES observations.
@@ -754,8 +760,8 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
 
     Parameters
     ----------
-    goeslc : `~sunpy.lightcurve.LightCurve`
-        LightCurve object containing GOES data.  The units of these
+    goests : `~sunpy.timeseries.XRSTimeSeries`
+        TimeSeries object containing GOES data.  The units of these
         data MUST be W/m^2 (flux), MK (temperature) and cm^-3
         (emission measure).  If LightCurve object does not contain
         temperature and emission measure values, they are calculated from
@@ -774,13 +780,13 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
 
     Returns
     -------
-    lc_new : `~sunpy.lightcurve.LightCurve`
+    ts_new : `~sunpy.timeseries.XRSTimeSeries`
         Contains same metadata and data as input LightCurve with the
         following additional data columns:
 
-        | lc_new.data.temperature - Array of temperature values [MK]
-        | lc_new.data.em - Array of volume emission measure values [cm**-3]
-        | lc_new.data.rad_loss_rate - radiative loss rate of the coronal soft
+        | ts_new.data.temperature - Array of temperature values [MK]
+        | ts_new.data.em - Array of volume emission measure values [cm**-3]
+        | ts_new.data.rad_loss_rate - radiative loss rate of the coronal soft
           X-ray-emitting plasma across all wavelengths [W]
 
     Notes
@@ -801,54 +807,57 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
 
     Examples
     --------
+    >>> import sunpy.timeseries as ts
     >>> from sunpy.instr.goes import calculate_radiative_loss_rate
-    >>> import sunpy.lightcurve as lc
-    >>> time1 = "2014-01-01 00:00:00"
-    >>> time2 = "2014-01-01 00:00:08"
-    >>> goeslc = lc.GOESLightCurve.create(time1, time2)  # doctest: +REMOTE_DATA
-    >>> goeslc.data  # doctest: +REMOTE_DATA
-                                        xrsa      xrsb
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004
-
-    >>> goeslc_new = calculate_radiative_loss_rate(goeslc)  # doctest: +REMOTE_DATA
-    >>> goeslc_new.data   # doctest: +NORMALIZE_WHITESPACE +REMOTE_DATA
-                                        xrsa      xrsb  temperature            em  \\
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004     6.270239  6.440648e+48
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004     6.270239  6.440648e+48
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004     6.273917  6.422208e+48
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004     6.304001  6.350370e+48
-    <BLANKLINE>
-                                rad_loss_rate
-    2014-01-01 00:00:00.421999   5.449144e+19
-    2014-01-01 00:00:02.468999   5.449144e+19
-    2014-01-01 00:00:04.518999   5.434659e+19
-    2014-01-01 00:00:06.564999   5.382823e+19
-
-
+    >>> from sunpy.data.sample import GOES_XRS_TIMESERIES  # doctest: +REMOTE_DATA
+    >>> goests = ts.TimeSeries(GOES_XRS_TIMESERIES)  # doctest: +REMOTE_DATA
+    >>> goests.data[0:10]  # doctest: +REMOTE_DATA
+                                           xrsa          xrsb
+    2011-06-06 23:59:59.961999893  1.000000e-09  1.887100e-07
+    2011-06-07 00:00:02.008999944  1.000000e-09  1.834600e-07
+    2011-06-07 00:00:04.058999896  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:06.104999900  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:08.151999950  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:10.201999903  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:12.248999953  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:14.298999906  1.000000e-09  1.834600e-07
+    2011-06-07 00:00:16.344999909  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:18.391999960  1.000000e-09  1.834600e-07
+    >>> goests_new = calculate_radiative_loss_rate(goests)  # doctest: +REMOTE_DATA
+    >>> goests_new.data[0:10]   # doctest:  +REMOTE_DATA
+                                           xrsa          xrsb  temperature            em  rad_loss_rate
+    2011-06-06 23:59:59.961999893  1.000000e-09  1.887100e-07     3.503510  2.190626e+48   1.781001e+19
+    2011-06-07 00:00:02.008999944  1.000000e-09  1.834600e-07     3.534262  2.055847e+48   1.660031e+19
+    2011-06-07 00:00:04.058999896  1.000000e-09  1.860900e-07     3.518700  2.122771e+48   1.719931e+19
+    2011-06-07 00:00:06.104999900  1.000000e-09  1.808400e-07     3.550100  1.990333e+48   1.601718e+19
+    2011-06-07 00:00:08.151999950  1.000000e-09  1.860900e-07     3.518700  2.122771e+48   1.719931e+19
+    2011-06-07 00:00:10.201999903  1.000000e-09  1.808400e-07     3.550100  1.990333e+48   1.601718e+19
+    2011-06-07 00:00:12.248999953  1.000000e-09  1.860900e-07     3.518700  2.122771e+48   1.719931e+19
+    2011-06-07 00:00:14.298999906  1.000000e-09  1.834600e-07     3.534262  2.055847e+48   1.660031e+19
+    2011-06-07 00:00:16.344999909  1.000000e-09  1.808400e-07     3.550100  1.990333e+48   1.601718e+19
+    2011-06-07 00:00:18.391999960  1.000000e-09  1.834600e-07     3.534262  2.055847e+48   1.660031e+19
     """
     if not download_dir:
         download_dir = get_and_create_download_dir()
     # Check that input argument is of correct type
-    if not isinstance(goeslc, lightcurve.LightCurve):
-        raise TypeError("goeslc must be a LightCurve object.")
+    if not isinstance(goests, timeseries.XRSTimeSeries):
+        raise TypeError("goests must be a XRSTimeSeries object.")
 
     # extract temperature and emission measure from GOESLightCurve
     # object and change type to that required by _calc_rad_loss().
     # If LightCurve object does not contain temperature and
     # emission measure, calculate using calculate_temperature_em()
-    if 'temperature' in goeslc.data and 'em' in goeslc.data:
+    if 'temperature' in goests.columns and 'em' in goests.columns:
         # Use copy.deepcopy for replicating meta and data so that input
         # lightcurve is not altered.
-        lc_new = lightcurve.LightCurve(meta=copy.deepcopy(goeslc.meta),
-                                       data=copy.deepcopy(goeslc.data))
+        ts_new = timeseries.XRSTimeSeries(meta=copy.deepcopy(goests.meta),
+                                          data=copy.deepcopy(goests.data),
+                                          units=copy.deepcopy(goests.units))
     else:
-        lc_new = calculate_temperature_em(goeslc)
-    temp = u.Quantity(np.asarray(lc_new.data.temperature, dtype=np.float64),
+        ts_new = calculate_temperature_em(goests)
+    temp = u.Quantity(np.asarray(ts_new.data.temperature, dtype=np.float64),
                       unit=u.MK)
-    em = u.Quantity(np.asarray(lc_new.data.em, dtype=np.float64),
+    em = u.Quantity(np.asarray(ts_new.data.em, dtype=np.float64),
                     unit=u.cm**(-3))
 
     # Find radiative loss rate with _calc_rad_loss()
@@ -856,13 +865,13 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
                                   download_dir=download_dir)
 
     # Enter results into new version of GOES LightCurve Object
-    lc_new.data["rad_loss_rate"] = rad_loss_out["rad_loss_rate"].to("W").value
+    ts_new = ts_new.add_column("rad_loss_rate", rad_loss_out['rad_loss_rate'].to("W"))
 
-    return lc_new
+    return ts_new
 
 
-@u.quantity_input(temp=u.MK, em=u.cm**(-3))
-def _calc_rad_loss(temp, em, obstime=None, force_download=False,
+@u.quantity_input
+def _calc_rad_loss(temp: u.MK, em: u.cm**-3, obstime=None, force_download=False,
                    download_dir=None):
     """
     Finds radiative loss rate of coronal plasma over all wavelengths.
@@ -886,7 +895,7 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
         at the same times corresponding to the temperatures in temp.
         Must be same length as temp.  Units=[cm**-3]
 
-    obstime : (optional) array-like of `datetime.datetime` objects
+    obstime : (optional) array-like of `~sunpy.time.parse_time` parsable objects
         Array of measurement times to which temperature and
         emission measure values correspond.  Must be same length
         as temp and em.  If this keyword is set, the integrated
@@ -899,7 +908,7 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
         launch of new GOES satellites.
         Default=False
 
-    download_dir : (optional) string
+    download_dir : (optional) str
         The directory to download the GOES radiative loss data file to.
         Default=SunPy default download directory
 
@@ -994,23 +1003,14 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
         if len(obstime) != n:
             raise IOError("obstime must have same number of elements as "
                           "temp and em.")
-        if type(obstime) == pandas.DatetimeIndex:
-            obstime = obstime.to_pydatetime
-        if any(type(obst) == str for obst in obstime):
-            parse_time(obstime)
-        if not all(type(obst) == datetime.datetime for obst in obstime):
-            raise TypeError("obstime must be an array-like whose elements are"
-                            " convertible to datetime objects.")
+
+        obstime = parse_time(obstime)
+
         # Check elements in obstime in chronological order
-        chrono_check = obstime-np.roll(obstime, 1)
-        chrono_check = chrono_check[1:]
-        if not all(chrono_check > datetime.timedelta(0)):
-            raise ValueError(
-                "Elements of obstime must be in chronological order.")
+        _assert_chrono_order(obstime)
         # Next, get measurement times in seconds from time of first
         # measurement.
-        obstime_seconds = np.array([(ot-obstime[0]).total_seconds()
-                                    for ot in obstime], dtype="float64")
+        obstime_seconds = (obstime - obstime[0]).sec
         # Finally, integrate using trapezoid rule
         rad_loss_int = trapz(rad_loss.value, obstime_seconds)
         rad_loss_int = u.Quantity(rad_loss_int, unit=rad_loss.unit*u.s)
@@ -1028,7 +1028,7 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
     return rad_loss_out
 
 
-def calculate_xray_luminosity(goeslc):
+def calculate_xray_luminosity(goests):
     """
     Calculates GOES solar X-ray luminosity.
 
@@ -1043,66 +1043,70 @@ def calculate_xray_luminosity(goeslc):
 
     Parameters
     ----------
-    goeslc : `~sunpy.lightcurve.LightCurve`
+    goests : `~sunpy.timeseries.XRSTimeSeries`
         LightCurve object containing GOES flux data which MUST
         be in units of W/m^2.
 
     Returns
     -------
-    lc_new : `~sunpy.lightcurve.LightCurve`
+    ts_new : `~sunpy.timeseries.XRSTimeSeries`
         Contains same metadata and data as input LightCurve with the
         following additional data columns;
 
-        | goeslc_new.data.luminosity_xrsa - Xray luminosity in 0.5-4A channel
+        | goests_new.data.luminosity_xrsa - Xray luminosity in 0.5-4A channel
           unit=[W]
-        | goeslc_new.data.luminosity_xrsb - Xray luminosity in 1-8A channel
+        | goests_new.data.luminosity_xrsb - Xray luminosity in 1-8A channel
           unit=[W]
 
     Examples
     --------
+    >>> import sunpy.timeseries as ts
     >>> from sunpy.instr.goes import calculate_xray_luminosity
-    >>> import sunpy.lightcurve as lc
-    >>> time1 = "2014-01-01 00:00:00"
-    >>> time2 = "2014-01-01 00:00:08"
-    >>> goeslc = lc.GOESLightCurve.create(time1, time2)  # doctest: +REMOTE_DATA
-    >>> goeslc.data  # doctest: +REMOTE_DATA
-                                        xrsa      xrsb
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004
-
-    >>> goeslc_new = calculate_xray_luminosity(goeslc)  # doctest: +REMOTE_DATA
-    >>> goeslc_new.data   # doctest: +NORMALIZE_WHITESPACE +REMOTE_DATA
-                                        xrsa      xrsb  luminosity_xrsa  \\
-    2014-01-01 00:00:00.421999  9.187300e-08  0.000004     2.498454e+16
-    2014-01-01 00:00:02.468999  9.187300e-08  0.000004     2.498454e+16
-    2014-01-01 00:00:04.518999  9.187300e-08  0.000004     2.498454e+16
-    2014-01-01 00:00:06.564999  9.298800e-08  0.000004     2.528776e+16
-    <BLANKLINE>
-                                luminosity_xrsb
-    2014-01-01 00:00:00.421999     9.544507e+17
-    2014-01-01 00:00:02.468999     9.544507e+17
-    2014-01-01 00:00:04.518999     9.530365e+17
-    2014-01-01 00:00:06.564999     9.530365e+17
-
+    >>> from sunpy.data.sample import GOES_XRS_TIMESERIES  # doctest: +REMOTE_DATA
+    >>> goests = ts.TimeSeries(GOES_XRS_TIMESERIES)  # doctest: +REMOTE_DATA
+    >>> goests.data[0:10]  # doctest: +REMOTE_DATA
+                                           xrsa          xrsb
+    2011-06-06 23:59:59.961999893  1.000000e-09  1.887100e-07
+    2011-06-07 00:00:02.008999944  1.000000e-09  1.834600e-07
+    2011-06-07 00:00:04.058999896  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:06.104999900  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:08.151999950  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:10.201999903  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:12.248999953  1.000000e-09  1.860900e-07
+    2011-06-07 00:00:14.298999906  1.000000e-09  1.834600e-07
+    2011-06-07 00:00:16.344999909  1.000000e-09  1.808400e-07
+    2011-06-07 00:00:18.391999960  1.000000e-09  1.834600e-07
+    >>> goests_new = calculate_xray_luminosity(goests)  # doctest: +REMOTE_DATA
+    >>> goests_new.data[0:10]   # doctest:  +REMOTE_DATA
+                                           xrsa          xrsb  luminosity_xrsa  luminosity_xrsb
+    2011-06-06 23:59:59.961999893  1.000000e-09  1.887100e-07     2.896209e+14     5.465435e+16
+    2011-06-07 00:00:02.008999944  1.000000e-09  1.834600e-07     2.896209e+14     5.313384e+16
+    2011-06-07 00:00:04.058999896  1.000000e-09  1.860900e-07     2.896209e+14     5.389555e+16
+    2011-06-07 00:00:06.104999900  1.000000e-09  1.808400e-07     2.896209e+14     5.237503e+16
+    2011-06-07 00:00:08.151999950  1.000000e-09  1.860900e-07     2.896209e+14     5.389555e+16
+    2011-06-07 00:00:10.201999903  1.000000e-09  1.808400e-07     2.896209e+14     5.237503e+16
+    2011-06-07 00:00:12.248999953  1.000000e-09  1.860900e-07     2.896209e+14     5.389555e+16
+    2011-06-07 00:00:14.298999906  1.000000e-09  1.834600e-07     2.896209e+14     5.313384e+16
+    2011-06-07 00:00:16.344999909  1.000000e-09  1.808400e-07     2.896209e+14     5.237503e+16
+    2011-06-07 00:00:18.391999960  1.000000e-09  1.834600e-07     2.896209e+14     5.313384e+16
     """
     # Check that input argument is of correct type
-    if not isinstance(goeslc, lightcurve.GOESLightCurve):
-        raise TypeError("goeslc must be a GOESLightCurve object.")
+    if not isinstance(goests, timeseries.XRSTimeSeries):
+        raise TypeError("goeslc must be a XRSTimeSeries object.")
     # Find temperature and emission measure with _goes_chianti_tem
-    lx_out = _goes_lx(u.Quantity(goeslc.data.xrsb, unit="W/m**2"),
-                      u.Quantity(goeslc.data.xrsa, unit="W/m**2"),
-                      date=str(goeslc.data.index[0]))
+    lx_out = _goes_lx(goests.quantity("xrsb"),
+                      goests.quantity("xrsa"),
+                      date=str(goests.data.index[0]))
     # Enter results into new version of GOES LightCurve Object
     # Use copy.deepcopy for replicating meta and data so that input
     # lightcurve is not altered.
-    lc_new = lightcurve.LightCurve(meta=copy.deepcopy(goeslc.meta),
-                                   data=copy.deepcopy(goeslc.data))
-    lc_new.data["luminosity_xrsa"] = lx_out["shortlum"].to("W").value
-    lc_new.data["luminosity_xrsb"] = lx_out["longlum"].to("W").value
+    ts_new = timeseries.XRSTimeSeries(meta=copy.deepcopy(goests.meta),
+                                      data=copy.deepcopy(goests.data),
+                                      units=copy.deepcopy(goests.units))
+    ts_new = ts_new.add_column("luminosity_xrsa", lx_out["shortlum"].to("W"))
+    ts_new = ts_new.add_column("luminosity_xrsb", lx_out["longlum"].to("W"))
 
-    return lc_new
+    return ts_new
 
 
 def _goes_lx(longflux, shortflux, obstime=None, date=None):
@@ -1126,12 +1130,12 @@ def _goes_lx(longflux, shortflux, obstime=None, date=None):
         Array containing the observed GOES/XRS short channel flux.
         Units=[W/m**2]
 
-    obstime : (optional) array-like of `datetime.datetime` objects
+    obstime : (optional) array-like of `~sunpy.time.parse_time` parsable objects
         Measurement times corresponding to each flux measurement.
         Assumes each pair of 0.5-4 and 1-8 angstrom flux measurements
         were taken simultaneously.
 
-    date : (optional) `datetime.datetime` object or valid date string.
+    date : (optional) `astropy.time.Time` object or valid date string.
         Date at which measurements were taken.  This is used to
         calculate the Sun-Earth distance.
         Default=None implies Sun-Earth distance is set to 1AU.
@@ -1159,16 +1163,16 @@ def _goes_lx(longflux, shortflux, obstime=None, date=None):
     Examples
     --------
     >>> from sunpy.instr.goes import _goes_lx
-    >>> from datetime import datetime
+    >>> from astropy.time import Time
     >>> from astropy.units.quantity import Quantity
     >>> longflux = Quantity([7e-6,7e-6,7e-6,7e-6,7e-6,7e-6], unit='W/m**2')
     >>> shortflux = Quantity([7e-7,7e-7,7e-7,7e-7,7e-7,7e-7], unit='W/m**2')
-    >>> obstime = np.array([datetime(2014,1,1,0,0,0),
-    ...                     datetime(2014,1,1,0,0,2),
-    ...                     datetime(2014,1,1,0,0,4),
-    ...                     datetime(2014,1,1,0,0,6),
-    ...                     datetime(2014,1,1,0,0,8),
-    ...                     datetime(2014,1,1,0,0,10),], dtype=object)
+    >>> obstime = Time(['2014-1-1T0:0:0',
+    ...                 '2014-1-1T0:0:2',
+    ...                 '2014-1-1T0:0:4',
+    ...                 '2014-1-1T0:0:6',
+    ...                 '2014-1-1T0:0:8',
+    ...                 '2014-1-1T0:0:10'])
     >>> lx_out = _goes_lx(longflux, shortflux, obstime)  # doctest: +REMOTE_DATA
     >>> lx_out["longlum"]  # doctest: +REMOTE_DATA
     <Quantity [1.96860565e+18, 1.96860565e+18, 1.96860565e+18, 1.96860565e+18,
@@ -1194,23 +1198,16 @@ def _goes_lx(longflux, shortflux, obstime=None, date=None):
         if not len(longflux) == len(shortflux) == len(obstime):
             raise ValueError("longflux, shortflux, and obstime must all have "
                              "same number of elements.")
-        if type(obstime) == pandas.DatetimeIndex:
-            obstime = obstime.to_pydatetime
-        if any(type(obst) == str for obst in obstime):
-            parse_time(obstime)
-        if not all(type(obst) == datetime.datetime for obst in obstime):
-            raise TypeError("obstime must be an array-like whose elements are"
-                            " convertible to datetime objects.")
+
+        obstime = parse_time(obstime)
+
         # Check elements in obstime in chronological order
-        chrono_check = obstime-np.roll(obstime, 1)
-        chrono_check = chrono_check[1:]
-        if not all(chrono_check > datetime.timedelta(0)):
-            raise ValueError(
-                "Elements of obstime must be in chronological order.")
+        _assert_chrono_order(obstime)
+
         # Next, get measurement times in seconds from time of first
         # measurement.
-        obstime_seconds = np.array([(ot-obstime[0]).total_seconds()
-                                    for ot in obstime], dtype="float64")
+        obstime_seconds = (obstime - obstime[0]).sec
+
         # Finally, integrate using trapezoid rule
         longlum_int = trapz(longlum.value, obstime_seconds)
         longlum_int = u.Quantity(longlum_int, unit=longlum.unit*u.s)
@@ -1233,8 +1230,8 @@ def _goes_lx(longflux, shortflux, obstime=None, date=None):
     return lx_out
 
 
-@u.quantity_input(flux=u.W/u.m/u.m)
-def _calc_xraylum(flux, date=None):
+@u.quantity_input
+def _calc_xraylum(flux: u.W/u.m/u.m, date=None):
     """
     Calculates solar luminosity based on observed flux observed at 1AU.
 
@@ -1249,7 +1246,7 @@ def _calc_xraylum(flux, date=None):
     flux : `~astropy.units.Quantity`
        Containing the observed solar flux.  Units=[W/m**2]
 
-    date : (optional) `datetime.datetime` object or valid date string
+    date : (optional) `astropy.time.Time` object or valid date str
         Used to calculate a more accurate Sun-Earth distance based on
         Earth's orbit at that date.  If date is None, Sun-Earth
         distance is set to 1AU.
@@ -1271,9 +1268,9 @@ def _calc_xraylum(flux, date=None):
     """
     if date is not None:
         date = parse_time(date)
-        xraylum = 4 * np.pi * get_sunearth_distance(date).to("m")**2 * flux
+        xraylum = 4 * np.pi * sun.earth_distance(date).to("m")**2 * flux
     else:
-        xraylum = 4 * np.pi * sun.constants.au.to("m")**2 * flux
+        xraylum = 4 * np.pi * constants.au.to("m")**2 * flux
     return xraylum
 
 
@@ -1299,8 +1296,8 @@ def flareclass_to_flux(flareclass):
     Examples
     --------
     >>> from sunpy.instr.goes import flareclass_to_flux
-    >>> flareclass_to_flux('A1.0') #doctest: +FLOAT_CMP
-    <Quantity 1e-08 W / m2>
+    >>> flareclass_to_flux('A1.0')
+    <Quantity 1.e-08 W / m2>
     >>> flareclass_to_flux('c4.7')
     <Quantity 4.7e-06 W / m2>
     >>> flareclass_to_flux('X2.4')
@@ -1316,8 +1313,8 @@ def flareclass_to_flux(flareclass):
     return float(flareclass[1:]) * GOES_CONVERSION_DICT[flareclass[0]]
 
 
-@u.quantity_input(goesflux=u.watt/u.m**2)
-def flux_to_flareclass(goesflux):
+@u.quantity_input
+def flux_to_flareclass(goesflux: u.watt/u.m**2):
     """
     Converts X-ray flux into the corresponding GOES flare class.
 
@@ -1373,3 +1370,11 @@ def flux_to_flareclass(goesflux):
         str_class = conversion_dict.get(u.Quantity(10 ** decade, "W/m**2"))
     goes_subclass = 10 ** -decade * goesflux.to('W/m**2').value
     return "{0}{1:.3g}".format(str_class, goes_subclass)
+
+
+def _assert_chrono_order(obstime):
+    chrono_check = np.array(obstime) - np.roll(obstime, 1)
+    chrono_check = chrono_check[1:]
+    if not all(val > TimeDelta(0*u.day) for val in chrono_check):
+        raise ValueError(
+            "Elements of obstime must be in chronological order.")
