@@ -10,6 +10,7 @@ from astropy.time import TimeDelta
 from sunpy.coordinates import HeliographicStonyhurst, Helioprojective, Heliocentric
 from sunpy.map import (all_coordinates_from_map, contains_full_disk, coordinate_is_on_solar_disk,
                        is_all_off_disk, is_all_on_disk, map_edges, on_disk_bounding_coordinates)
+from sunpy.map.header_helper import get_observer_meta
 from sunpy.time import parse_time
 from sunpy.util import expand_list
 
@@ -404,17 +405,20 @@ def _warp_sun_coordinates(xy, smap, new_observer, **diff_rot_kwargs):
                                      obstime=new_observer.obstime,
                                      observer=new_observer,
                                      frame=Helioprojective)
+
         heliographic_coordinate = output_hpc_coords.transform_to(HeliographicStonyhurst)
+        # Now transform the HGS coordinates to the obstime of the input map (to account for movement of Earth)
+        heliographic_coordinate = heliographic_coordinate.transform_to(HeliographicStonyhurst(obstime=smap.date))
 
         # Compute the differential rotation.
         drot = diff_rot(interval, heliographic_coordinate.lat.to(u.degree), **diff_rot_kwargs)
 
-        # Add in the differential rotation shift
-        rotated_coord = SkyCoord(heliographic_coordinate.lon + drot,
+        # The change in longitude is negative because we are mapping from the
+        # new coordinates to the old.
+        rotated_coord = SkyCoord(heliographic_coordinate.lon - drot,
                                  heliographic_coordinate.lat,
                                  heliographic_coordinate.radius,
-                                 obstime=new_observer.obstime,
-                                 observer=new_observer,
+                                 obstime=heliographic_coordinate.obstime,
                                  frame=HeliographicStonyhurst)
 
         # As seen from the map observer, which coordinates are on disk and which are behind the Sun.
@@ -579,9 +583,7 @@ def differential_rotate(smap, observer=None, time=None, **diff_rot_kwargs):
         out_meta.pop(key)
 
     # Add a new HGS observer
-    out_meta['hglt_obs'] = new_observer.lat.value
-    out_meta['hgln_obs'] = new_observer.lon.value
-    out_meta['dsun_obs'] = new_observer.radius.to(u.m).value
+    out_meta.update(get_observer_meta(new_observer, out_meta['rsun_ref']*u.m))
 
     if is_sub_full_disk:
         # Define a new reference pixel and the value at the reference pixel.
